@@ -68,6 +68,7 @@ public:
 
 	void currentElementTest();
 
+	void resetElements();
 	void clearElements();
 
 	void setSampleFile(const char *pszSampleFile, bool bSync = false);
@@ -248,6 +249,7 @@ public:
 	const char *sampleFile() const;
 
 	drumkv1_sample *sample() const;
+	uint32_t length() const;
 
 	void setReverse(bool bReverse);
 	bool isReverse() const;
