@@ -1000,17 +1000,8 @@ bool drumkv1_jack_application::setup (void)
 
 	m_pDrumk = new drumkv1_jack(client_name);
 
-	if (m_bGui) {
+	if (m_bGui)
 		m_pWidget = new drumkv1widget_jack(m_pDrumk);
-	//	m_pWidget->show();
-		if (m_presets.isEmpty())
-			m_pWidget->initPreset();
-		else
-			m_pWidget->loadPreset(m_presets.first());
-	}
-	else
-	if (!m_presets.isEmpty())
-		drumkv1_param::loadPreset(m_pDrumk, m_presets.first());
 
 #ifdef CONFIG_NSM
 	// Check whether to participate into a NSM session...
@@ -1039,8 +1030,16 @@ bool drumkv1_jack_application::setup (void)
 	}
 	else
 #endif	// CONFIG_NSM
-	if (m_pWidget)
+	if (m_pWidget) {
 		m_pWidget->show();
+		if (m_presets.isEmpty())
+			m_pWidget->initPreset();
+		else
+			m_pWidget->loadPreset(m_presets.first());
+	}
+	else
+	if (!m_presets.isEmpty())
+		drumkv1_param::loadPreset(m_pDrumk, m_presets.first());
 
 	// Start watchdog timer...
 	watchdog_start();
@@ -1089,9 +1088,9 @@ void drumkv1_jack_application::openSession (void)
 
 	bool bOpen = false;
 
-	QFileInfo fi(path_name, "session." PROJECT_NAME);
+	QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
 	if (!fi.exists())
-		fi.setFile(path_name, display_name + '.' + PROJECT_NAME);
+		fi.setFile(path_name, "session." PROJECT_NAME);
 	if (fi.exists()) {
 		const QString& sFilename = fi.absoluteFilePath();
 		if (m_pWidget) {
@@ -1127,9 +1126,8 @@ void drumkv1_jack_application::saveSession (void)
 
 //	const QString& client_name = m_pNsmClient->client_name();
 	const QString& path_name = m_pNsmClient->path_name();
-//	const QString& display_name = m_pNsmClient->display_name();
-//	const QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
-	const QFileInfo fi(path_name, "session." PROJECT_NAME);
+	const QString& display_name = m_pNsmClient->display_name();
+	QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
 
 	const bool bSave
 		= drumkv1_param::savePreset(m_pDrumk, fi.absoluteFilePath(), true);
@@ -1138,6 +1136,11 @@ void drumkv1_jack_application::saveSession (void)
 		? drumkv1_nsm::ERR_OK
 		: drumkv1_nsm::ERR_GENERAL);
 	m_pNsmClient->dirty(false);
+
+	fi.setFile(path_name, "session." PROJECT_NAME);
+	if (fi.exists())
+		QFile::remove(fi.absoluteFilePath());
+
 }
 
 
