@@ -83,6 +83,9 @@ public:
 	static QString noteName(int note);
 	static QString completeNoteName(int note);
 
+	// Update visual configuration.
+	void updateConfig();
+
 public slots:
 
 	// Preset file I/O.
